@@ -15,7 +15,6 @@ class ImageItem : public QQuickPaintedItem
     Q_OBJECT
 
     Q_PROPERTY(QImage image READ image WRITE setImage NOTIFY imageChanged RESET resetImage)
-    Q_PROPERTY(bool smooth READ smooth WRITE setSmooth)
     Q_PROPERTY(int nativeWidth READ nativeWidth NOTIFY nativeWidthChanged)
     Q_PROPERTY(int nativeHeight READ nativeHeight NOTIFY nativeHeightChanged)
     Q_PROPERTY(int paintedWidth READ paintedWidth NOTIFY paintedWidthChanged)
@@ -43,9 +42,6 @@ public:
     QImage image() const;
     void resetImage();
 
-    void setSmooth(const bool smooth);
-    bool smooth() const;
-
     int nativeWidth() const;
     int nativeHeight() const;
 
@@ -73,7 +69,11 @@ Q_SIGNALS:
     void horizontalPaddingChanged();
 
 protected:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) override;
+#else
+    void geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry) override;
+#endif
 
 private:
     QImage m_image;
